pub struct ReleaseValidator;Implementations
Sourceimpl ReleaseValidator
impl ReleaseValidator
Sourcepub fn validate(
cli_input: &ReleaseCliInput,
prerelease_state: Option<&PrereleaseState>,
graduation_state: Option<&GraduationState>,
packages: &[PackageInfo],
project_kind: &ProjectKind,
) -> Result<ValidatedReleaseConfig, ValidationErrors>
pub fn validate( cli_input: &ReleaseCliInput, prerelease_state: Option<&PrereleaseState>, graduation_state: Option<&GraduationState>, packages: &[PackageInfo], project_kind: &ProjectKind, ) -> Result<ValidatedReleaseConfig, ValidationErrors>
Errors
Returns ValidationErrors if any validation rule fails. All errors
are collected before returning, so the caller receives a complete
list of issues rather than just the first one.