InitOperation

Struct InitOperation 

pub struct InitOperation<P, M = (), I = ()> { /* private fields */ }

Implementations

Source

impl<P> InitOperation<P, (), ()>
where P: ProjectProvider,

pub fn new(project_provider: P) -> Self

pub fn prepare_simple(&self, start_path: &Path) -> Result<InitPlan>

Errors

Returns an error if the project cannot be discovered.

pub fn execute_simple_plan( &self, start_path: &Path, plan: &InitPlan, ) -> Result<InitOutput>

Errors

Returns an error if the changeset directory cannot be created.

pub fn execute_simple(&self, start_path: &Path) -> Result<InitOutput>

Errors

Returns an error if the project cannot be discovered or the changeset directory cannot be created.

Source

impl<P, M, I> InitOperation<P, M, I>
where P: ProjectProvider,

pub fn with_manifest_writer<M2>(self, writer: M2) -> InitOperation<P, M2, I>

pub fn with_interaction_provider<I2>( self, provider: I2, ) -> InitOperation<P, M, I2>

Source

impl<P, M, I> InitOperation<P, M, I>

pub fn prepare(&self, start_path: &Path, input: &InitInput) -> Result<InitPlan>

Errors

Returns an error if the project cannot be discovered or configuration cannot be built (e.g., interactive prompts fail).

pub fn execute_plan( &self, start_path: &Path, plan: &InitPlan, ) -> Result<InitOutput>

Errors

Returns an error if the changeset directory cannot be created or configuration cannot be written.

pub fn execute( &self, start_path: &Path, input: &InitInput, ) -> Result<InitOutput>

Errors

Returns an error if the project cannot be discovered, the changeset directory cannot be created, or configuration cannot be written.