pub trait ChangesetReader: Send + Sync {
// Required methods
fn read_changeset(&self, path: &Path) -> Result<Changeset>;
fn list_changesets(&self, changeset_dir: &Path) -> Result<Vec<PathBuf>>;
fn list_consumed_changesets(
&self,
changeset_dir: &Path,
) -> Result<Vec<PathBuf>>;
}Expand description
Reads changeset files from the filesystem.
See the module-level documentation for details on the consumed changeset lifecycle.
Required Methods
Sourcefn read_changeset(&self, path: &Path) -> Result<Changeset>
fn read_changeset(&self, path: &Path) -> Result<Changeset>
Errors
Returns an error if the file cannot be read or parsed.