InteractionProvider

Trait InteractionProvider 

pub trait InteractionProvider: Send + Sync {
    // Required methods
    fn select_packages(
        &self,
        available: &[PackageInfo],
    ) -> Result<PackageSelection>;
    fn select_bump_type(&self, package_name: &str) -> Result<BumpSelection>;
    fn select_category(&self) -> Result<CategorySelection>;
    fn get_description(&self) -> Result<DescriptionInput>;
}

Required Methods

fn select_packages(&self, available: &[PackageInfo]) -> Result<PackageSelection>

Errors

Returns an error if the interaction cannot be completed.

fn select_bump_type(&self, package_name: &str) -> Result<BumpSelection>

Errors

Returns an error if the interaction cannot be completed.

fn select_category(&self) -> Result<CategorySelection>

Errors

Returns an error if the interaction cannot be completed.

fn get_description(&self) -> Result<DescriptionInput>

Errors

Returns an error if the interaction cannot be completed.

Implementors