pub struct InitOperation<P, M = (), I = ()> { /* private fields */ }Implementations
Sourceimpl<P> InitOperation<P, (), ()>where
P: ProjectProvider,
impl<P> InitOperation<P, (), ()>where
P: ProjectProvider,
pub fn new(project_provider: P) -> Self
Sourcepub fn prepare_simple(&self, start_path: &Path) -> Result<InitPlan>
pub fn prepare_simple(&self, start_path: &Path) -> Result<InitPlan>
Errors
Returns an error if the project cannot be discovered.
Sourcepub fn execute_simple_plan(
&self,
start_path: &Path,
plan: &InitPlan,
) -> Result<InitOutput>
pub fn execute_simple_plan( &self, start_path: &Path, plan: &InitPlan, ) -> Result<InitOutput>
Errors
Returns an error if the changeset directory cannot be created.
Sourcepub fn execute_simple(&self, start_path: &Path) -> Result<InitOutput>
pub fn execute_simple(&self, start_path: &Path) -> Result<InitOutput>
Errors
Returns an error if the project cannot be discovered or the changeset directory cannot be created.
Sourceimpl<P, M, I> InitOperation<P, M, I>where
P: ProjectProvider,
impl<P, M, I> InitOperation<P, M, I>where
P: ProjectProvider,
pub fn with_manifest_writer<M2>(self, writer: M2) -> InitOperation<P, M2, I>
pub fn with_interaction_provider<I2>( self, provider: I2, ) -> InitOperation<P, M, I2>
Sourceimpl<P, M, I> InitOperation<P, M, I>
impl<P, M, I> InitOperation<P, M, I>
Sourcepub fn prepare(&self, start_path: &Path, input: &InitInput) -> Result<InitPlan>
pub fn prepare(&self, start_path: &Path, input: &InitInput) -> Result<InitPlan>
Errors
Returns an error if the project cannot be discovered or configuration cannot be built (e.g., interactive prompts fail).
Sourcepub fn execute_plan(
&self,
start_path: &Path,
plan: &InitPlan,
) -> Result<InitOutput>
pub fn execute_plan( &self, start_path: &Path, plan: &InitPlan, ) -> Result<InitOutput>
Errors
Returns an error if the changeset directory cannot be created or configuration cannot be written.