pub trait InitInteractionProvider: Send + Sync {
// Required methods
fn configure_git_settings(
&self,
context: ProjectContext,
) -> Result<Option<GitSettingsInput>>;
fn configure_changelog_settings(
&self,
context: ProjectContext,
) -> Result<Option<ChangelogSettingsInput>>;
fn configure_version_settings(&self) -> Result<Option<VersionSettingsInput>>;
fn configure_filtering_settings(
&self,
) -> Result<Option<FilteringSettingsInput>>;
}Required Methods
Sourcefn configure_git_settings(
&self,
context: ProjectContext,
) -> Result<Option<GitSettingsInput>>
fn configure_git_settings( &self, context: ProjectContext, ) -> Result<Option<GitSettingsInput>>
Errors
Returns an error if the interaction cannot be completed.
Sourcefn configure_changelog_settings(
&self,
context: ProjectContext,
) -> Result<Option<ChangelogSettingsInput>>
fn configure_changelog_settings( &self, context: ProjectContext, ) -> Result<Option<ChangelogSettingsInput>>
For single-package projects, the changelog location question should be skipped
(defaulting to root), but comparison_links should still be prompted.
Errors
Returns an error if the interaction cannot be completed.
Sourcefn configure_version_settings(&self) -> Result<Option<VersionSettingsInput>>
fn configure_version_settings(&self) -> Result<Option<VersionSettingsInput>>
Errors
Returns an error if the interaction cannot be completed.
Sourcefn configure_filtering_settings(&self) -> Result<Option<FilteringSettingsInput>>
fn configure_filtering_settings(&self) -> Result<Option<FilteringSettingsInput>>
Errors
Returns an error if the interaction cannot be completed.