pub trait InteractionProvider: Send + Sync {
// Required methods
fn select_packages(
&self,
available: &[PackageInfo],
) -> Result<PackageSelection>;
fn select_bump_type(&self, package_name: &str) -> Result<BumpSelection>;
fn select_category(&self) -> Result<CategorySelection>;
fn get_description(&self) -> Result<DescriptionInput>;
}Required Methods
Sourcefn select_packages(&self, available: &[PackageInfo]) -> Result<PackageSelection>
fn select_packages(&self, available: &[PackageInfo]) -> Result<PackageSelection>
Errors
Returns an error if the interaction cannot be completed.
Sourcefn select_bump_type(&self, package_name: &str) -> Result<BumpSelection>
fn select_bump_type(&self, package_name: &str) -> Result<BumpSelection>
Errors
Returns an error if the interaction cannot be completed.
Sourcefn select_category(&self) -> Result<CategorySelection>
fn select_category(&self) -> Result<CategorySelection>
Errors
Returns an error if the interaction cannot be completed.
Sourcefn get_description(&self) -> Result<DescriptionInput>
fn get_description(&self) -> Result<DescriptionInput>
Errors
Returns an error if the interaction cannot be completed.